#!/bin/bash

# Metadata
# Description: Disable certain services and update configuration files.
# Author: Overland-Tandberg Engineering
# Usage: ./QS-security-patch-09212023.sh

# Paths
APACHE_INIT="/etc/init.d/S99apache"
NTP_INIT="/etc/init.d/S49ntp"
SSHD_CONFIG="/etc/ssh/sshd_config"
SYSCTL_CONF="/etc/sysctl.conf"
TEMP_CRON="/tmp/temp_crontab"

# Backup existing configurations
cp $SSHD_CONFIG "${SSHD_CONFIG}.backup"
cp $SYSCTL_CONF "${SYSCTL_CONF}.backup"

# Stop running services and disable automatic execution in the future
# Web server and UI
$APACHE_INIT stop
[ $? -ne 0 ] && echo "Error stopping Apache service" && exit 1

mv $APACHE_INIT "${APACHE_INIT/S99/K99}"
[ $? -ne 0 ] && echo "Error renaming Apache init script" && exit 1

# NTP Service
$NTP_INIT stop
[ $? -ne 0 ] && echo "Error stopping NTP service" && exit 1

mv $NTP_INIT "${NTP_INIT/S49/K49}"
[ $? -ne 0 ] && echo "Error renaming NTP init script" && exit 1


# Set up replacement files and configurations
# Define the new crontab 
new_cron_schedule=$(cat <<EOF
*/5 * * * * /opt/tandberg/bin/vtx-logrotate-wrapper.sh
5 * * * * /opt/tandberg/bin/vtx-flush-cache.sh
0 1 * * *  /usr/sbin/ntpd -gq > /dev/null 2>&1
EOF
)

# Define the replacement sshd_config
new_sshd_config=$(cat <<EOF
PermitRootLogin yes
StrictModes no
PubkeyAuthentication yes
AuthorizedKeysFile /etc/ssh/authorized_keys
PasswordAuthentication no
PermitEmptyPasswords no
Subsystem	sftp	/usr/libexec/sftp-server
MACS umac-128-etm@openssh.com,hmac-sha2-256-etm@openssh.com,hmac-sha2-512-etm@openssh.com,umac-128@openssh.com,hmac-sha2-256,hmac-sha2-512
EOF
)

# Define the new sysctl.conf
new_sysctl_conf=$(cat <<EOF
# /etc/sysctl.conf
kernel.core_pattern = /var/core/core-%e
fs.suid_dumpable = 1
net.ipv4.tcp_timestamps=0
EOF
)

# Replace configuration files per definitions above

# Replace the updated crontab from the temporary file
echo "$new_cron_schedule" > $TEMP_CRON
crontab $TEMP_CRON && rm $TEMP_CRON
[ $? -ne 0 ] && echo "Error updating crontab" && exit 1


# Replace sshd_config
echo "$new_sshd_config" > $SSHD_CONFIG
[ $? -ne 0 ] && echo "Error updating sshd config" && exit 1

# Replace sysctl_conf
echo "$new_sysctl_conf" > $SYSCTL_CONF
[ $? -ne 0 ] && echo "Error updating sysctl config" && exit 1

# Declare success for user
echo "Status: Successfully completed"
